--
-- IH1480
-- Implementation of combine functions and leavers
-- 
-- @author  Knagsted
-- @date  17/09/09
--
-- Thankyou to Bayn for allowing me to reuse parts from the JD 660 script in this implementation
--
-- Do not edit without my permission
--

IH1480 = {};

function IH1480.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Combine, specializations);
end;

function IH1480:load(xmlFile)
	self.keys = {};
    local i=0;
    while true do
        local baseName = string.format("vehicle.keys.input(%d)", i);
        local inputName = getXMLString(xmlFile, baseName.. "#name");
        if inputName == nil then
            break;
        end;
        local inputKey = getXMLString(xmlFile, baseName.. "#key");
        if Input[inputKey] == nil then
            print("Error: invalid key '" .. inputKey .. "'  for input event '" .. inputName .. "'");
            break;
        end;
        self.keys[inputName] = Input[inputKey];
        i = i+1;
    end;

    self.lastGrainLevel = 0;

    self.pipeGrainParticleSystem = {};
    self.pipeGrainParticleSystemindex = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.pipeGrainParticleSystem#index"));
    Utils.loadParticleSystem(xmlFile, self.pipeGrainParticleSystem, "vehicle.pipeGrainParticleSystem", self.pipeGrainParticleSystemindex, false, nil, self.baseDirectory);
    
    self.pipeRapeParticleSystem = {};
    self.pipeRapeParticleSystemindex = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.pipeRapeParticleSystem#index"));
    Utils.loadParticleSystem(xmlFile, self.pipeRapeParticleSystem, "vehicle.pipeRapeParticleSystem", self.pipeRapeParticleSystemindex, false, nil, self.baseDirectory);
	
	self.extraPipeWheatParticleSystem = {};
    self.extraPipeWheatParticleSystemindex = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.extraPipeWheatParticleSystem#index"));
    Utils.loadParticleSystem(xmlFile, self.extraPipeWheatParticleSystem, "vehicle.extraPipeWheatParticleSystem", self.extraPipeWheatParticleSystemindex, false, nil, self.baseDirectory);
    
    self.extraPipeRapeParticleSystem = {};
    self.extraPipeRapeParticleSystemindex = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.extraPipeRapeParticleSystem#index"));
    Utils.loadParticleSystem(xmlFile, self.extraPipeRapeParticleSystem, "vehicle.extraPipeRapeParticleSystem", self.extraPipeRapeParticleSystemindex, false, nil, self.baseDirectory);
	
    self.strawSpreaderAnz = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.strawSpreader#count"),0);
    self.strawSpreader = {};
    for i=1, self.strawSpreaderAnz do
        local objname = string.format("vehicle.strawSpreader.strawSpreader" .. "%d",i);
        self.strawSpreader[i] = {};
        self.strawSpreader[i].rotNode = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, objname .. "#rotNode"));
        self.strawSpreader[i].speed = Utils.getNoNil(getXMLInt(xmlFile,  objname .. "#rotSpeed"), 1)/1000;
    end;

    local rotationPartNodeTanknadel = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.rotationPartTanknadel#index"));
    if rotationPartNodeTanknadel ~= nil then
        self.rotationPartTanknadel = {};
        self.rotationPartTanknadel.node = rotationPartNodeTanknadel;

        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationPartTanknadel#minRot"));
        self.rotationPartTanknadel.minRot = {};
        self.rotationPartTanknadel.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationPartTanknadel.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationPartTanknadel.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationPartTanknadel#maxRot"));
        self.rotationPartTanknadel.maxRot = {};
        self.rotationPartTanknadel.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationPartTanknadel.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationPartTanknadel.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.rotationPartTanknadel.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationPartTanknadel#rotTime"), 2)*1000;
        self.rotationPartTanknadel.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationPartTanknadel#touchRotLimit"), 10));
    end;
	
	local rotationPartNodeTanknadel2 = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.rotationPartTanknadel2#index"));
    if rotationPartNodeTanknadel2 ~= nil then
        self.rotationPartTanknadel2 = {};
        self.rotationPartTanknadel2.node = rotationPartNodeTanknadel2;

        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationPartTanknadel2#minRot"));
        self.rotationPartTanknadel2.minRot = {};
        self.rotationPartTanknadel2.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationPartTanknadel2.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationPartTanknadel2.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationPartTanknadel2#maxRot"));
        self.rotationPartTanknadel2.maxRot = {};
        self.rotationPartTanknadel2.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationPartTanknadel2.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationPartTanknadel2.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.rotationPartTanknadel2.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationPartTanknadel2#rotTime"), 2)*1000;
        self.rotationPartTanknadel2.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationPartTanknadel2#touchRotLimit"), 10));
    end;
	
	local rotationPartNodeVoltnadel = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.rotationPartVoltnadel#index"));
    if rotationPartNodeVoltnadel ~= nil then
        self.rotationPartVoltnadel = {};
        self.rotationPartVoltnadel.node = rotationPartNodeVoltnadel;

        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationPartVoltnadel#minRot"));
        self.rotationPartVoltnadel.minRot = {};
        self.rotationPartVoltnadel.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationPartVoltnadel.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationPartVoltnadel.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationPartVoltnadel#maxRot"));
        self.rotationPartVoltnadel.maxRot = {};
        self.rotationPartVoltnadel.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationPartVoltnadel.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationPartVoltnadel.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.rotationPartVoltnadel.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationPartVoltnadel#rotTime"), 2)*1000;
        self.rotationPartVoltnadel.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationPartVoltnadel#touchRotLimit"), 10));
    end;
	
	local rotationPartNodeOilPreasurenadel = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.rotationPartOilPreasurenadel#index"));
    if rotationPartNodeOilPreasurenadel ~= nil then
        self.rotationPartOilPreasurenadel = {};
        self.rotationPartOilPreasurenadel.node = rotationPartNodeOilPreasurenadel;

        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationPartOilPreasurenadel#minRot"));
        self.rotationPartOilPreasurenadel.minRot = {};
        self.rotationPartOilPreasurenadel.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationPartOilPreasurenadel.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationPartOilPreasurenadel.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationPartOilPreasurenadel#maxRot"));
        self.rotationPartOilPreasurenadel.maxRot = {};
        self.rotationPartOilPreasurenadel.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationPartOilPreasurenadel.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationPartOilPreasurenadel.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.rotationPartOilPreasurenadel.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationPartOilPreasurenadel#rotTime"), 2)*1000;
        self.rotationPartOilPreasurenadel.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationPartOilPreasurenadel#touchRotLimit"), 10));
    end;
	
	local rotationPartNodeTempnadel = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.rotationPartTempnadel#index"));
    if rotationPartNodeTempnadel ~= nil then
        self.rotationPartTempnadel = {};
        self.rotationPartTempnadel.node = rotationPartNodeTempnadel;

        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationPartTempnadel#minRot"));
        self.rotationPartTempnadel.minRot = {};
        self.rotationPartTempnadel.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationPartTempnadel.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationPartTempnadel.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationPartTempnadel#maxRot"));
        self.rotationPartTempnadel.maxRot = {};
        self.rotationPartTempnadel.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationPartTempnadel.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationPartTempnadel.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.rotationPartTempnadel.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationPartTempnadel#rotTime"), 2)*1000;
        self.rotationPartTempnadel.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationPartTempnadel#touchRotLimit"), 10));
    end;
	
    self.incrementRotation = true;
    self.exhaustCover = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.exhaustCover#index"));
    if self.exhaustCover ~= nil then
        self.exhaustRotationSpeed = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.exhaustCover#rotationSpeed"), 0);
	  self.exhaustRotationMax = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.exhaustCover#rotationMax"), 0);
	  self.exhaustRotationMin = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.exhaustCover#rotationMin"), 0);
	  self.currentRotation = self.exhaustRotationMin;
    end;
	
	self.fan = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.fan#index"));
    self.fanRotation = 0;


  -- Steering Wheel movements --

local rotationNodeColonne = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.rotationColonne#index"));
    if rotationNodeColonne ~= nil then
        self.rotationColonne = {};
        self.rotationColonne.node = rotationNodeColonne;
        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationColonne#minRot"));
        self.rotationColonne.minRot = {};
        self.rotationColonne.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationColonne.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationColonne.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationColonne#maxRot"));
        self.rotationColonne.maxRot = {};
        self.rotationColonne.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationColonne.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationColonne.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.rotationColonne.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationColonne#rotTime"), 2)*1000;
        self.rotationColonne.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationColonne#touchRotLimit"), 10));
    end; 

	-- Ladder movements --
	
	local rotationNodeEchelle = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.rotationEchelle#index"));
    if rotationNodeEchelle ~= nil then
        self.rotationEchelle = {};
        self.rotationEchelle.node = rotationNodeEchelle;
        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationEchelle#minRot"));
        self.rotationEchelle.minRot = {};
        self.rotationEchelle.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationEchelle.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationEchelle.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.rotationEchelle#maxRot"));
        self.rotationEchelle.maxRot = {};
        self.rotationEchelle.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.rotationEchelle.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.rotationEchelle.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.rotationEchelle.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationEchelle#rotTime"), 2)*1000;
        self.rotationEchelle.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.rotationEchelle#touchRotLimit"), 10));
    end;

	-- Seperator movements -- 
		local seperatorPartNode1 = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.seperatorPart1#index"));
    if seperatorPartNode1 ~= nil then
        self.seperatorPart1 = {};
        self.seperatorPart1.node = seperatorPartNode1;

        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.seperatorPart1#minRot"));
        self.seperatorPart1.minRot = {};
        self.seperatorPart1.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.seperatorPart1.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.seperatorPart1.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.seperatorPart1#maxRot"));
        self.seperatorPart1.maxRot = {};
        self.seperatorPart1.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.seperatorPart1.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.seperatorPart1.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.seperatorPart1.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.seperatorPart1#rotTime"), 2);
        self.seperatorPart1.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.seperatorPart1#touchRotLimit"), 10));
    end;
	
	local seperatorPartNode2 = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.seperatorPart2#index"));
    if seperatorPartNode2 ~= nil then
        self.seperatorPart2 = {};
        self.seperatorPart2.node = seperatorPartNode2;

        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.seperatorPart2#minRot"));
        self.seperatorPart2.minRot = {};
        self.seperatorPart2.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.seperatorPart2.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.seperatorPart2.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.seperatorPart2#maxRot"));
        self.seperatorPart2.maxRot = {};
        self.seperatorPart2.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.seperatorPart2.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.seperatorPart2.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.seperatorPart2.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.seperatorPart2#rotTime"), 2);
        self.seperatorPart2.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.seperatorPart2#touchRotLimit"), 10));
    end;
	
	local seperatorPartNode3 = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.seperatorPart3#index"));
    if seperatorPartNode3 ~= nil then
        self.seperatorPart3 = {};
        self.seperatorPart3.node = seperatorPartNode3;

        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.seperatorPart3#minRot"));
        self.seperatorPart3.minRot = {};
        self.seperatorPart3.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.seperatorPart3.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.seperatorPart3.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.seperatorPart3#maxRot"));
        self.seperatorPart3.maxRot = {};
        self.seperatorPart3.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.seperatorPart3.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.seperatorPart3.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.seperatorPart3.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.seperatorPart3#rotTime"), 2);
        self.seperatorPart3.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.seperatorPart3#touchRotLimit"), 10));
    end;
	
	local seperatorPartNode4 = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.seperatorPart4#index"));
    if seperatorPartNode4 ~= nil then
        self.seperatorPart4 = {};
        self.seperatorPart4.node = seperatorPartNode4;

        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.seperatorPart4#minRot"));
        self.seperatorPart4.minRot = {};
        self.seperatorPart4.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.seperatorPart4.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.seperatorPart4.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.seperatorPart4#maxRot"));
        self.seperatorPart4.maxRot = {};
        self.seperatorPart4.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.seperatorPart4.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.seperatorPart4.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.seperatorPart4.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.seperatorPart4#rotTime"), 2);
        self.seperatorPart4.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.seperatorPart4#touchRotLimit"), 10));
    end;
	
	local seperatorPartNode5 = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.seperatorPart5#index"));
    if seperatorPartNode5 ~= nil then
        self.seperatorPart5 = {};
        self.seperatorPart5.node = seperatorPartNode5;

        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.seperatorPart5#minRot"));
        self.seperatorPart5.minRot = {};
        self.seperatorPart5.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.seperatorPart5.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.seperatorPart5.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.seperatorPart5#maxRot"));
        self.seperatorPart5.maxRot = {};
        self.seperatorPart5.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.seperatorPart5.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.seperatorPart5.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.seperatorPart5.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.seperatorPart5#rotTime"), 2);
        self.seperatorPart5.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.seperatorPart5#touchRotLimit"), 10));
    end;
	
	
	local seperatorPartNode6 = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.seperatorPart6#index"));
    if seperatorPartNode6 ~= nil then
        self.seperatorPart6 = {};
        self.seperatorPart6.node = seperatorPartNode6;

        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.seperatorPart6#minRot"));
        self.seperatorPart6.minRot = {};
        self.seperatorPart6.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.seperatorPart6.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.seperatorPart6.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.seperatorPart6#maxRot"));
        self.seperatorPart6.maxRot = {};
        self.seperatorPart6.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.seperatorPart6.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.seperatorPart6.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.seperatorPart6.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.seperatorPart6#rotTime"), 2);
        self.seperatorPart6.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.seperatorPart6#touchRotLimit"), 10));
    end;
	
	self.seperatorPart7 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.seperatorPart7#index"));
	
	-- Sounds --
	
    BuseSoundFile = Utils.getFilename("BuseSound.ogg", self.baseDirectory);
    self.BuseSoundId = createSample("BuseSound");
    loadSample(self.BuseSoundId, BuseSoundFile, false);
    self.BusePlaying = false;
   
    BatteurSoundFile = Utils.getFilename("Treshing.ogg", self.baseDirectory);
    self.BatteurSoundId = createSample("BatteurSound");
    loadSample(self.BatteurSoundId, BatteurSoundFile, false);
    self.BatteurPlaying = false;
	
    BatteurStartSoundFile = Utils.getFilename("startTreshing2.ogg", self.baseDirectory);
    self.BatteurStartSoundId = createSample("BatteurStartSound");
    loadSample(self.BatteurStartSoundId, BatteurStartSoundFile, false);
    self.BatteurStartPlaying = false;

    BatteurStopSoundFile = Utils.getFilename("treshingStop2.ogg", self.baseDirectory);
    self.BatteurStopSoundId = createSample("BatteurStopSound");
    loadSample(self.BatteurStopSoundId, BatteurStopSoundFile, false);
    self.BatteurStopPlaying = false;

	self.rundumleuchtenAnz = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.rundumleuchten#count"),0);
    self.rundumleuchtenKey = getXMLString(xmlFile, "vehicle.rundumleuchten#key");
    self.rundumleuchtenAn = false;
    self.rundumleuchten = {};
    for i=1, self.rundumleuchtenAnz do
        local objname = string.format("vehicle.rundumleuchten.light" .. "%d",i);
        self.rundumleuchten[i] = {};
        self.rundumleuchten[i].rotNode = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, objname .. "#rotNode"));
        self.rundumleuchten[i].light = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, objname .. "#light"));
        self.rundumleuchten[i].source = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, objname .. "#lightsource"));
        self.rundumleuchten[i].speed = Utils.getNoNil(getXMLInt(xmlFile,  objname .. "#rotSpeed"), 1)/1000;
        self.rundumleuchten[i].emit = Utils.getNoNil(getXMLBool(xmlFile, objname .. "#emitLight"), true);
        if not self.rundumleuchten[i].emit and self.rundumleuchten[i].source ~= nil then
           setVisibility(self.rundumleuchten[i].source, false);
        end;
    end;

    self.gearShifter = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.gearShifter#index"));
    self.hydroStatHandle = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.hydroStatHandle#index"));
	self.rpmHandle = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.rpmHandle#index"));

    self.Rouleau = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Rouleau#index"));
    self.Helice1 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Helice1#index"));
    self.Helice2 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Helice2#index"));
    self.Rotor = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Rotor#index"));
    self.retroG = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.retroG#index"));
    self.retroD = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.retroD#index"));
	
	-- Discs ---
	self.disc1 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.disc1#index"));
	self.disc2 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.disc2#index"));
	self.disc3 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.disc3#index"));
	self.disc4 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.disc4#index"));
	self.disc5 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.disc5#index"));
	self.disc6 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.disc6#index"));
	self.disc7 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.disc7#index"));
	self.disc8 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.disc8#index"));
	
	-- Cab controllers
	self.seperatorOnSwitch = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.seperatorOnSwitch#index"));
	self.rotorOnSwitch = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.rotorOnSwitch#index"));
	self.fanOnSwitch = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.fanOnSwitch#index"));
	self.lightOnSwitch = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.lightOnSwitch#index"));
	self.workLightOnSwitch = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.workLightOnSwitch#index"));
	self.reelOnSwitch = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.reelOnSwitch#index"));
	self.grainPipeOutSwitch = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.grainPipeOutSwitch#index"));
	self.key = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.key#index"));
	self.feederSpeed = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.feederSpeed#index"));
	self.reelSpeedSwitch = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.reelSpeedSwitch#index"));
	self.reelLiftSwitch = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.reelLiftSwitch#index"));
	self.reelForwardSwitch = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.reelForwardSwitch#index"));
	self.cutterRaiseSwitch = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.cutterRaiseSwitch#index"));
	self.cutterLevelIndicator = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.cutterLevelIndicator#index"));
	self.displaySelectorKnob = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.displaySelectorKnob#index"));
	
	self.attacherJointRot = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.attacherJointRot#index"));
	
	local grainUnloadHandleNode = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.grainUnloadHandle#index"));
    if grainUnloadHandleNode ~= nil then
        self.grainUnloadHandle = {};
        self.grainUnloadHandle.node = grainUnloadHandleNode;

        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.grainUnloadHandle#minRot"));
        self.grainUnloadHandle.minRot = {};
        self.grainUnloadHandle.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.grainUnloadHandle.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.grainUnloadHandle.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.grainUnloadHandle#maxRot"));
        self.grainUnloadHandle.maxRot = {};
        self.grainUnloadHandle.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.grainUnloadHandle.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.grainUnloadHandle.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.grainUnloadHandle.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.grainUnloadHandle#rotTime"), 2);
        self.grainUnloadHandle.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.grainUnloadHandle#touchRotLimit"), 10));
    end;
	
	-- Graintank auger
    self.grainTankAuger = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.grainTankAuger#index"));
    self.grainTankAugerRotation = 0;

	-- Digital Display digits
	self.numDigitOne = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.displayDigitOne#count"), 0);
	self.digitOne = {};
    for i=1, self.numDigitOne do
        local objname = string.format("vehicle.displayDigitOne.digit" .. "%d", i);
		self.digitOne[i] = {};
        self.digitOne[i].rotNode = Utils.indexToObject(self.components, getXMLString(xmlFile, objname .. "#rotNode"));
		setVisibility(self.digitOne[i].rotNode,false);
    end;
	setVisibility(self.digitOne[self.numDigitOne].rotNode,true);
	
	self.numDigitTwo = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.displayDigitTwo#count"), 0);
	self.digitTwo = {};
    for i=1, self.numDigitTwo do
        local objname = string.format("vehicle.displayDigitTwo.digit" .. "%d", i);
		self.digitTwo[i] = {};
        self.digitTwo[i].rotNode = Utils.indexToObject(self.components, getXMLString(xmlFile, objname .. "#rotNode"));
		setVisibility(self.digitTwo[i].rotNode,false);
    end;
	setVisibility(self.digitTwo[self.numDigitTwo].rotNode,true);

	self.numDigitThree = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.displayDigitThree#count"), 0);
	self.digitThree = {};
    for i=1, self.numDigitThree do
        local objname = string.format("vehicle.displayDigitThree.digit" .. "%d", i);
		self.digitThree[i] = {};
        self.digitThree[i].rotNode = Utils.indexToObject(self.components, getXMLString(xmlFile, objname .. "#rotNode"));
		setVisibility(self.digitThree[i].rotNode,false);
    end;
	setVisibility(self.digitThree[self.numDigitThree].rotNode,true);
	
	self.numDigitFour = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.displayDigitFour#count"), 0);
	self.digitFour = {};
    for i=1, self.numDigitFour do
        local objname = string.format("vehicle.displayDigitFour.digit" .. "%d", i);
		self.digitFour[i] = {};
        self.digitFour[i].rotNode = Utils.indexToObject(self.components, getXMLString(xmlFile, objname .. "#rotNode"));
		setVisibility(self.digitFour[i].rotNode,false);
    end;
	setVisibility(self.digitFour[self.numDigitFour].rotNode,true);



	-- Init of self values
    self.ThreshingActive = false;
	self.ThreshingSound = false;
	self.Echelle = false;	
    self.setGrainTankFillLevel = SpecializationUtil.callSpecializationsFunction("setGrainTankFillLevel");
	self.HUDActive = true;
	self.RetroActive = false;
	self.BatteurOK = false;
	self.TreshedNumber = 0;
	self.TreshedTotalNumber = 0;
	self.strawToggleTime = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.strawParticleSystems#toggleTime"), 3500);
	-- HUD --
	
	self.HUDpath = Utils.getFilename("HUD_Controls.png", self.baseDirectory);
	self.HUDWidth = 0.100;
    self.HUDHeight = 0.700;
	self.HUDPoxX = 0.9;
    self.HUDPoxY = 0.18
    self.HUDOverlay = Overlay:new("HUD", self.HUDpath, self.HUDPoxX, self.HUDPoxY, self.HUDWidth, self.HUDHeight);
	
	self.rotationDirection = true;
	self.lastGrainLevel = self.grainTankFillLevel;
	self.lastGrainPipeRotation = 0;
	self.lastAttacherRotation = 0;
	self.engineRunTime = 0;
	self.feederSpeedValue = 5;
	self.reelSpeedValue = self.feederSpeedValue/4;
	self.sidearmRotation = 0;
	self.sidearmTranslation = -0.75;
	self.reelSpeedAdjustMode = 0;
	self.sideArmAdjustMode = 0;
	self.sideArmFwdAdjustMode = 0;
	self.attacherRot = 0;
	self.attacherHightAdjustMode = 0;
	self.feederSpeedAdjustMode = 0;
	self.autoHeader = true;
	self.cutterLevelIndicatorHeight = 0;
	self.displaySelectorMode = 0;
	self.orgUnloadCapacity = self.grainTankUnloadingCapacity;
	self.displayValue = 0;
	self.prevousDigitFour = self.numDigitFour;
	self.prevousDigitThree = self.numDigitThree;
	self.prevousDigitTwo = self.numDigitTwo;
	self.prevousDigitOne = self.numDigitOne;	
end;

function IH1480:loadFromAttributesAndNodes(xmlFile, key, resetVehicles)
   local TreshedTotalNumber =  Utils.getNoNil(getXMLFloat(xmlFile, key.."#TreshedTotalNumber"),0);
   self.TreshedTotalNumber = TreshedTotalNumber;
    return BaseMission.VEHICLE_LOAD_OK;
end;

function IH1480:getSaveAttributesAndNodes(nodeIdent)
   local TreshedTotalNumber= Utils.getNoNil(self.TreshedTotalNumber, 10);
    local attributes = 'TreshedTotalNumber="'..string.format("%.1f",TreshedTotalNumber)..'"';
   return attributes, nil;
end;


function IH1480:delete()
    delete(self.BuseSoundId);
    delete(self.BatteurStartSoundId);
    delete(self.BatteurStopSoundId);
    delete(self.BatteurSoundId);
end;

function IH1480:mouseEvent(posX, posY, isDown, isUp, button)
end;

function IH1480:keyEvent(unicode, sym, modifier, isDown)

		--if isDown and sym == Input.KEY_l and self.isMotorStarted then
			--renderText(0.5, 0.9350, 0.040, string.format());
    	if isDown and sym == self.keys.Batteur and self.isMotorStarted then
			self.ThreshingActive = not self.ThreshingActive;
			self.ThreshingSound = not self.ThreshingSound;
			self.BatteurOK = not self.BatteurOK;
			local BatteurSoundOffset = 4050;
			self.playBatteurSoundTime = self.time+BatteurSoundOffset;
		end

		if isDown and sym == self.keys.HUD then
			self.HUDActive = not self.HUDActive;
		end;

		if isDown and sym == self.keys.Echelle then
			self.Echelle = not self.Echelle;
		end;

		if isDown and sym == self.keys.retro then
			self.RetroActive = not self.RetroActive;
		end;
		
		if isDown and sym == Input.KEY_7 then
			self.feederSpeedAdjustMode = 1;
		else 
			self.feederSpeedAdjustMode = 0;
		end;
		
		if isDown and sym == Input.KEY_6 then
			self.feederSpeedAdjustMode = -1;
		end;
		
		if isDown and sym == Input.KEY_9 then
			self.reelSpeedAdjustMode = 1;
		else
			self.reelSpeedAdjustMode = 0;
		end;
		
		if isDown and sym == Input.KEY_8 then
			self.reelSpeedAdjustMode = -1;
		end;
		
		if isDown and sym == Input.KEY_4 then
			self.sideArmAdjustMode = -1;
		else
			self.sideArmAdjustMode = 0;
		end;
		
		if isDown and sym == Input.KEY_5 then
			self.sideArmAdjustMode = 1;
		end;
		
		if isDown and sym == Input.KEY_KP_4 then
			self.sideArmFwdAdjustMode = 1;
		else
			self.sideArmFwdAdjustMode = 0;
		end;
		
		if isDown and sym == Input.KEY_KP_6 then
			self.sideArmFwdAdjustMode = -1;
		end;
		
		if isDown and sym == Input.KEY_KP_enter then
			self.autoHeader = not self.autoHeader;
		end;
		
		if isDown and sym == Input.KEY_m then
			if self.displaySelectorMode < 3 then
				self.displaySelectorMode = self.displaySelectorMode + 1;
			else
				self.displaySelectorMode = 0;
			end;
		end;

    if self.isEntered then
      if self.rundumleuchtenKey ~= nil then
         if isDown and sym == Input.KEY_r then
           self.rundumleuchtenAn = not self.rundumleuchtenAn;
           for i=1, self.rundumleuchtenAnz do
             setVisibility(self.rundumleuchten[i].light, self.rundumleuchtenAn);
           end;
         end;
      end;
    end;

end;

function IH1480:update(dt)
	--if self.lightsActive then 
		--renderText(0.5, 0.9350, 0.040, string.format("Lights on"));
	--else
		--renderText(0.5, 0.9350, 0.040, string.format("Lights off"));
	--end;
		if not self.autoHeader and self.isEntered and not self.isHired then
			if InputBinding.isPressed(InputBinding.HEADER_DOWN) then
				if self.attacherRot < 30 then
					self.attacherRot = self.attacherRot + 0.25;
				end;
			elseif InputBinding.isPressed(InputBinding.HEADER_UP) then
				if self.attacherRot > -3 then
					self.attacherRot = self.attacherRot - 0.25;
				end;
			end;
		end;
		
	
	local rpm = self.rpmNum;
	
	if self.rpmNum == 3 then
		rpm = 2.5;
	end;

	if self.isMotorStarted then
		rotate(self.fan, dt * 0.004 * rpm, 0, 0);
		self.engineRunTime = dt + self.engineRunTime;
	else
		self.engineRunTime = 0;
	end;
	
	if self.feederSpeedAdjustMode == 1 then
		if self.feederSpeedValue < 25 then
			self.feederSpeedValue = self.feederSpeedValue + 0.15;
		end;
	elseif self.feederSpeedAdjustMode == -1 then
		if self.feederSpeedValue > 2 then
			self.feederSpeedValue = self.feederSpeedValue - 0.15;
		end;
	end;
	
	if self.reelSpeedAdjustMode == -1 then
		if self.reelSpeedValue > 0.2 then
			self.reelSpeedValue = self.reelSpeedValue - 0.03;
		end;
	elseif self.reelSpeedAdjustMode == 1 then
		if self.reelSpeedValue < 3.5 then
			self.reelSpeedValue = self.reelSpeedValue + 0.03;
		end;
	end;
	
	if self.sideArmAdjustMode == -1 then
		if self.sidearmRotation > -15 then
			self.sidearmRotation = self.sidearmRotation - 0.2;
		end
	elseif self.sideArmAdjustMode == 1 then
		if self.sidearmRotation < 15 then
			self.sidearmRotation = self.sidearmRotation + 0.2;
		end
	end;
	
	
	if self.sideArmFwdAdjustMode == -1 then
		if self.sidearmTranslation < -0.65 then
			self.sidearmTranslation = self.sidearmTranslation + 0.003;
		end
	elseif self.sideArmFwdAdjustMode == 1 then
		if self.sidearmTranslation > -0.94 then
			self.sidearmTranslation = self.sidearmTranslation - 0.003;
		end
	end;
	
	if self.attacherJointRot ~= nil then
		if self.autoHeader then
			local x,y,z = getRotation(self.attacherJointRot);
			self.attacherRot = x/3.14 * 180;
		end;
	end;

	local procent = self.grainTankFillLevel/self.grainTankCapacity*100;
	if procent >= 89 then
		if not self.rundumleuchtenAn then
			self.rundumleuchtenAn = true;
			for i=1, self.rundumleuchtenAnz do
				setVisibility(self.rundumleuchten[i].light, self.rundumleuchtenAn);
			end;
		end;
	end;
	
	-- Digital Display handling
	if self.isEntered then
		setVisibility(self.digitTwo[11].rotNode,false);
		if self.displaySelectorMode == 0 then
			self.displayValue = self.rpms[2][self.rpmNum];
		elseif self.displaySelectorMode == 1 then
			self.displayValue = math.floor(self.lastSpeed * 3600 * 100);
			if self.isMotorStarted then 
				setVisibility(self.digitTwo[11].rotNode,true);
			else
				setVisibility(self.digitTwo[11].rotNode,false);
			end;
		elseif self.displaySelectorMode == 2 then
			if self.ThreshingActive then
				self.displayValue = math.floor((self.rpms[2][self.rpmNum])/2.35);
			else
				self.displayValue = 0;
			end;
		else
			if self.ThreshingActive then
				self.displayValue = math.floor((self.rpms[2][self.rpmNum])/2.65);
			else
				self.displayValue = 0;
			end;
		end;
		local displayValue = self.displayValue;
		
		--if self.displaySelectorMode == 1 then
			--displayValue = math.floor(displayValue);
		--end;

		--renderText(0.5, 0.9, 0.040, string.format(displayValue));
		-- Handle the digits in the display
		if self.isMotorStarted then
			local thousends = math.floor(displayValue/1000);
			local displayIndex = thousends;
			if self.prevousDigitFour ~= thousends then
				if self.prevousDigitFour > 0 then
					setVisibility(self.digitFour[self.prevousDigitFour].rotNode,false);
				end;
				if displayIndex == 0 then
					displayIndex = self.numDigitFour; 
				end;
				setVisibility(self.digitFour[displayIndex].rotNode,true);
			end;
			self.prevousDigitFour = displayIndex;
				
			displayValue = displayValue - thousends * 1000;
			local hundreds = math.floor(displayValue/100);
			displayIndex = hundreds;
			if self.prevousDigitThree ~= hundreds then
				if self.prevousDigitThree > 0 then
					setVisibility(self.digitThree[self.prevousDigitThree].rotNode,false);
				end;
				if displayIndex == 0 and thousends == 0 then
					displayIndex = self.numDigitThree;
				elseif displayIndex == 0 then 
					if thousends > 0 then
						displayIndex = 10;
					end;
				end;
				setVisibility(self.digitThree[displayIndex].rotNode,true);
			end;
			self.prevousDigitThree = displayIndex;
			
			displayValue = displayValue - hundreds * 100;
			local tens = math.floor(displayValue/10);
			displayIndex = tens;
			if self.prevousDigitTwo ~= tens then
				if self.prevousDigitTwo > 0 then
					setVisibility(self.digitTwo[self.prevousDigitTwo].rotNode,false);
				end;
				if displayIndex == 0 and hundreds == 0 then
					displayIndex = self.numDigitTwo;
				elseif displayIndex == 0 then 
					if hundreds > 0 or thousends > 0 then
						displayIndex = 10;
					end;
				end;
				setVisibility(self.digitTwo[displayIndex].rotNode,true);
			end;
			self.prevousDigitTwo = displayIndex;
			
			displayValue = displayValue - tens * 10;
			local ones = math.floor(displayValue);
			displayIndex = ones;
			if self.prevousDigitOne ~= ones then
				if self.prevousDigitOne > 0 then
					setVisibility(self.digitOne[self.prevousDigitOne].rotNode,false);
				end;

				if displayIndex == 0 then
					displayIndex = 10;
				end;
				--renderText(0.5, 0.65, 0.040, string.format(displayIndex));
				setVisibility(self.digitOne[displayIndex].rotNode,true);
			end;
			self.prevousDigitOne = displayIndex;
		else
			if self.prevousDigitThree > 0 then
				setVisibility(self.digitThree[self.prevousDigitThree].rotNode,false);
			end;
			self.prevousDigitOne = self.numDigitOne;
			if self.prevousDigitThree > 0 then
				setVisibility(self.digitThree[self.prevousDigitThree].rotNode,false);
			end;
			self.prevousDigitTwo = self.numDigitTwo;
			if self.prevousDigitTwo > 0 then
				setVisibility(self.digitTwo[self.prevousDigitTwo].rotNode,false);
			end;
			self.prevousDigitThree = self.numDigitThree;
			if self.prevousDigitOne > 0 then
				setVisibility(self.digitOne[self.prevousDigitOne].rotNode,false);
			end;
			self.prevousDigitFour = self.numDigitFour;
			setVisibility(self.digitOne[self.numDigitOne].rotNode,true);
			setVisibility(self.digitTwo[self.numDigitTwo].rotNode,true);
			setVisibility(self.digitThree[self.numDigitThree].rotNode,true);
			setVisibility(self.digitTwo[self.numDigitFour].rotNode,true);
		end;
	end;
	
	-- Display handling done
	
	-- Higher unload rate pr. rpm and extra pipe particls
	self.grainTankUnloadingCapacity = (self.rpms[2][self.rpmNum]/self.rpms[2][1]) * self.orgUnloadCapacity;
	
	if self.unloading and self.grainTankUnloadingCapacity > self.orgUnloadCapacity then 
		if self.currentGrainTankFruitType == FruitUtil.FRUITTYPE_RAPE then
			Utils.setEmittingState(self.extraPipeRapeParticleSystem, true);
		else
			Utils.setEmittingState(self.extraPipeWheatParticleSystem, true);
		end;
	else
		Utils.setEmittingState(self.extraPipeRapeParticleSystem, false);
		Utils.setEmittingState(self.extraPipeWheatParticleSystem, false);
	end;

	
	-- Grain tank particles
	for cutter,implement in pairs(self.attachedCutters) do
                if cutter.reelStarted then
				if self.lastGrainLevel < self.grainTankFillLevel then 
					if self.currentGrainTankFruitType == FruitUtil.FRUITTYPE_RAPE then
						Utils.setEmittingState(self.pipeRapeParticleSystem, true);
					else
						Utils.setEmittingState(self.pipeGrainParticleSystem, true);
					end;
				else
			  		Utils.setEmittingState(self.pipeGrainParticleSystem, false);
					Utils.setEmittingState(self.pipeRapeParticleSystem, false);
				end;
			
		    else 
			Utils.setEmittingState(self.pipeGrainParticleSystem, false);
			Utils.setEmittingState(self.pipeRapeParticleSystem, false);
		    end;
	end;

	-- Seperator movements --
	
	if self.ThreshingActive then 
		if self.seperatorPart1 ~= nil then
            local x, y, z = getRotation(self.seperatorPart1.node);
            local minRot = self.seperatorPart1.minRot;
			local maxRot = self.seperatorPart1.maxRot;
            local eps = self.seperatorPart1.touchRotLimit;

            if math.abs(x-minRot[1]) < eps and math.abs(y-minRot[2]) < eps and math.abs(z-minRot[3]) < eps then
				self.rotationDirection = false;
			elseif math.abs(maxRot[1]-x) < eps and math.abs(maxRot[2]-y) < eps and math.abs(maxRot[3]-z) < eps then
				self.rotationDirection = true;
			end;
		end;
			
		if self.seperatorPart1 ~= nil then
			local x, y, z = getRotation(self.seperatorPart1.node);
			local rot = {x,y,z};
			local newRot = Utils.getMovedLimitedValues(rot, self.seperatorPart1.maxRot, self.seperatorPart1.minRot, 3, self.seperatorPart1.rotTime / rpm, dt, self.rotationDirection);
			setRotation(self.seperatorPart1.node, unpack(newRot));
		end;
		
		if self.seperatorPart2 ~= nil then
			local x, y, z = getRotation(self.seperatorPart2.node);
			local rot = {x,y,z};
			local newRot = Utils.getMovedLimitedValues(rot, self.seperatorPart2.maxRot, self.seperatorPart2.minRot, 3, self.seperatorPart2.rotTime / rpm, dt, self.rotationDirection);
			setRotation(self.seperatorPart2.node, unpack(newRot));
		end;
		
		if self.seperatorPart3 ~= nil then
			local x, y, z = getRotation(self.seperatorPart3.node);
			local rot = {x,y,z};
			local newRot = Utils.getMovedLimitedValues(rot, self.seperatorPart3.maxRot, self.seperatorPart3.minRot, 3, self.seperatorPart3.rotTime / rpm, dt, self.rotationDirection);
			setRotation(self.seperatorPart3.node, unpack(newRot));
		end;
		
		if self.seperatorPart4 ~= nil then
			local x, y, z = getRotation(self.seperatorPart4.node);
			local rot = {x,y,z};
			local newRot = Utils.getMovedLimitedValues(rot, self.seperatorPart4.maxRot, self.seperatorPart4.minRot, 3, self.seperatorPart4.rotTime / rpm, dt, self.rotationDirection);
			setRotation(self.seperatorPart4.node, unpack(newRot));
		end;
		
		if self.seperatorPart5 ~= nil then
			local x, y, z = getRotation(self.seperatorPart5.node);
			local rot = {x,y,z};
			local newRot = Utils.getMovedLimitedValues(rot, self.seperatorPart5.maxRot, self.seperatorPart5.minRot, 3, self.seperatorPart5.rotTime / rpm, dt, self.rotationDirection);
			setRotation(self.seperatorPart5.node, unpack(newRot));
		end;
		
		if self.seperatorPart6 ~= nil then
			local x, y, z = getRotation(self.seperatorPart6.node);
			local rot = {x,y,z};
			local newRot = Utils.getMovedLimitedValues(rot, self.seperatorPart6.maxRot, self.seperatorPart6.minRot, 3, self.seperatorPart6.rotTime / rpm, dt, self.rotationDirection);
			setRotation(self.seperatorPart6.node, unpack(newRot));
		end;
		
		rotate(self.seperatorPart7, dt*0.012*rpm, 0, 0);
	end;

		if self.isEntered then
		  if self.rundumleuchtenAn == true then
			setVisibility(self.roundLightDisplay, true);
		  else
			setVisibility(self.roundLightDisplay, false);
	    	  end;
    		end;

	if self.isEntered or self.isHired then
        if self.rundumleuchtenAnz > 0 then
          if self.rundumleuchtenAn then
            for i=1, self.rundumleuchtenAnz do
              rotate(self.rundumleuchten[i].rotNode, 0, dt*self.rundumleuchten[i].speed, 0);
            end;
          end;
        end;
      end;

-- Movements --

		local doRotate = self.rotationColonneMax or self.rotationColonneMin 
	if self.rotationColonne ~= nil and doRotate then
        local x, y, z = getRotation(self.rotationColonne.node);
        local rot = {x,y,z};
        local newRot = Utils.getMovedLimitedValues(rot, self.rotationColonne.maxRot, self.rotationColonne.minRot, 3, self.rotationColonne.rotTime, dt, not self.rotationColonneMax);
        setRotation(self.rotationColonne.node, unpack(newRot));
    end;	
	
	local doRotate = self.rotationEchelleMax or self.rotationEchelleMin 
	if self.rotationEchelle ~= nil and doRotate then
        local x, y, z = getRotation(self.rotationEchelle.node);
        local rot = {x,y,z};
        local newRot = Utils.getMovedLimitedValues(rot, self.rotationEchelle.maxRot, self.rotationEchelle.minRot, 3, self.rotationEchelle.rotTime, dt, not self.rotationEchelleMax);
        setRotation(self.rotationEchelle.node, unpack(newRot));
    end;
	
	if self.exhaustCover ~= nil then
		if self.isMotorStarted then
			local rpm = math.max(self.rpms[2][self.rpmNum]/85,0);
			local rpmDeltaMotion = math.max(self.rpms[2][self.rpmNum]/800,0);
				 
			  if self.incrementRotation == true then 
					self.currentRotation = self.currentRotation + self.exhaustRotationSpeed;
			else
				self.currentRotation = self.currentRotation - self.exhaustRotationSpeed;
			end;

			if self.currentRotation >= (self.exhaustRotationMax - rpmDeltaMotion)then
				self.incrementRotation = false;
			elseif self.currentRotation <= (self.exhaustRotationMin + rpmDeltaMotion) then
				self.incrementRotation = true;
			end;
			  setRotation(self.exhaustCover,Utils.degToRad(self.currentRotation+rpm), 0, 0);
		else 
			setRotation(self.exhaustCover, 0, 0, 0);
		end;
	end;

		-- Echelle --
		
	if self.Echelle then
		self.rotationEchelleMax = true;
		self.rotationEchelleMin = false;
	else
		self.rotationEchelleMax = false;
		self.rotationEchelleMin = true;
	end;
	
	
	-- Threshing Sounds --

	
	if self.ThreshingSound and self:getIsActiveForSound() then
        if not self.BatteurStartPlaying then
			playSample(self.BatteurStartSoundId, 1, 1, 0);
			self.BatteurStartPlaying = true;
			stopSample(self.BatteurStopSoundId);
			self.BatteurStopPlaying = false;
		end;
	else
        if self.BatteurStartPlaying then
			stopSample(self.BatteurStartSoundId);
			self.BatteurStartPlaying = false;
			playSample(self.BatteurStopSoundId, 1, 1, 0);
			self.BatteurStopPlaying = true;	
		end;
	end;
	
	if self.ThreshingSound and self:getIsActiveForSound() then
		if self.playBatteurSoundTime <= self.time then
			if not self.BatteurPlaying then
				playSample(self.BatteurSoundId, 0, 1, 0);
				self.BatteurPlaying = true;
			end;
		end;
	else
			if self.BatteurPlaying then
				stopSample(self.BatteurSoundId);
				self.BatteurPlaying = false;
			end;
	end;

-- Threshing Movements --
	local feederRotation = 0.001 * self.feederSpeedValue;
	local reelRotation = 0.001 * self.reelSpeedValue;
	
	if self.ThreshingActive then 
		rotate(self.Rouleau, dt*feederRotation, 0, 0);
		rotate(self.Helice2, 0, -dt*0.004 * rpm, 0);
		rotate(self.Helice1, 0, dt*0.004 * rpm, 0);
		rotate(self.grainTankAuger, 0, dt*0.007* rpm, 0);

		rotate(self.disc8, dt*0.01* rpm, 0, 0);
		rotate(self.disc7, dt*0.03* rpm, 0, 0);
		rotate(self.disc6, dt*0.018* rpm, 0, 0);
		rotate(self.disc5, -dt*0.03* rpm, 0, 0);
		rotate(self.disc4, -dt*0.015* rpm, 0, 0);
		rotate(self.disc3, -dt*0.015* rpm, 0, 0);
		rotate(self.disc2, -dt*0.015* rpm, 0, 0);
		rotate(self.disc1, -dt*0.015* rpm, 0, 0);

	end;
	
-- Cutter movements -- 
	
	for cutter,implement in pairs(self.attachedCutters) do
		if cutter.reelStarted and self.isMotorStarted then
			if cutter.rollNode ~= nil then
				rotate(cutter.rollNode, -1 * dt*feederRotation, 0, 0);
			end;
			if cutter.myRollNode ~= nil then
				cutter.myRollSpeed = -1 * dt*feederRotation;
			end;
			
			if cutter.reelNode ~= nil then
				rotate(cutter.reelNode, -1 * dt*reelRotation, 0, 0);
			end;
			if cutter.myReelNode ~= nil then
				cutter.myReelSpeed = -1 * dt*reelRotation;
			end;
			
		end;
		
		if cutter.sideArm ~= nil then
			setRotation(cutter.sideArm, Utils.degToRad(self.sidearmRotation) ,0 ,0);
		end
		
		
		if cutter.sideArmFwdTranslator ~= nil then
			setTranslation(cutter.sideArmFwdTranslator, 0,0.32,self.sidearmTranslation);
		end
		
		cutter.sideArmAdjustMode = self.sideArmAdjustMode; 
	end;
	
-- Manual attacher movement
	if not self.isHired and not self.autoHeader then
		if self.attacherJointRot ~= nil then
			setRotation(self.attacherJointRot, Utils.degToRad(self.attacherRot),0 ,0);
		end;
	end;
	


-- CAB movements

	if self.attacherJointRot ~= nil then
		local xAttacher, yAttacher, zAttacher = getRotation(self.attacherJointRot);
		if xAttacher ~= nil then
			if xAttacher < self.lastAttacherRotation then
				setRotation(self.cutterRaiseSwitch, Utils.degToRad(90) ,Utils.degToRad(90) ,Utils.degToRad(12));
			elseif xAttacher > self.lastAttacherRotation then
				setRotation(self.cutterRaiseSwitch, Utils.degToRad(90) ,Utils.degToRad(90) ,Utils.degToRad(-12));
			else
				setRotation(self.cutterRaiseSwitch, Utils.degToRad(90) ,Utils.degToRad(90) ,0);
			end;
		end;
		
		self.cutterLevelIndicatorHeight = (((xAttacher/3.14)*180) / 30) * -0.3;
		if self.cutterLevelIndicator ~= nil then
			setTranslation(self.cutterLevelIndicator,0, self.cutterLevelIndicatorHeight + 0.01,-0.03);
		end;
		
		self.lastAttacherRotation = xAttacher;
	end;
	
	if self.displaySelectorKnob ~= nil then
		setRotation(self.displaySelectorKnob, 0,Utils.degToRad(self.displaySelectorMode * 35),0);
	end;
	
	if self.ThreshingActive then
		setRotation(self.seperatorOnSwitch, Utils.degToRad(6) ,0 ,0);
		setRotation(self.rotorOnSwitch, Utils.degToRad(9) ,0 ,0);
		setRotation(self.fanOnSwitch, Utils.degToRad(9) ,0 ,0);
	else
		setRotation(self.seperatorOnSwitch, Utils.degToRad(-6) ,0 ,0);
		setRotation(self.rotorOnSwitch, Utils.degToRad(-6) ,0 ,0);
		setRotation(self.fanOnSwitch, Utils.degToRad(-6) ,0 ,0);
	end;
	
	if self.lightsActive then
		setRotation(self.lightOnSwitch, Utils.degToRad(9) ,0 ,0);
		setRotation(self.workLightOnSwitch, Utils.degToRad(9) ,0 ,0);
	else
		setRotation(self.lightOnSwitch, Utils.degToRad(-6) ,0 ,0);
		setRotation(self.workLightOnSwitch, Utils.degToRad(-6) ,0 ,0);
	end;
	
	for cutter,implement in pairs(self.attachedCutters) do
		if cutter.reelStarted then
			setRotation(self.reelOnSwitch, Utils.degToRad(6) ,0 ,0);
		else
			setRotation(self.reelOnSwitch, Utils.degToRad(-6) ,0 ,0);
		end;
	end;
	
	if self.pipe ~= nil then
		local xPipe, yPipe, zPipe = getRotation(self.pipe);
		
		if yPipe ~= nil then
			if yPipe < self.lastGrainPipeRotation then
				setRotation(self.grainPipeOutSwitch, Utils.degToRad(6) ,0 ,0);
			elseif yPipe > self.lastGrainPipeRotation then
				setRotation(self.grainPipeOutSwitch, Utils.degToRad(-6) ,0 ,0);
			else
				setRotation(self.grainPipeOutSwitch, 0 ,0 ,0);
			end;
		end;
		
		self.lastGrainPipeRotation = yPipe;
	end;
	
	if self.key ~= nil then
		if self.isMotorStarted and self.engineRunTime < 1500 then
			setRotation(self.key, 0,Utils.degToRad(-90) ,Utils.degToRad(-24));
		elseif self.isMotorStarted then
			setRotation(self.key, 0,Utils.degToRad(-50) ,Utils.degToRad(-24));
		else
			setRotation(self.key, 0,Utils.degToRad(0) ,Utils.degToRad(-24));
		end;
	end;
	
	if self.feederSpeed ~= nil then
		setRotation(self.feederSpeed, Utils.degToRad(-180),Utils.degToRad(self.feederSpeedValue * 20) ,0);
	end;
	
	if self.reelSpeedSwitch ~= nil then
		setRotation(self.reelSpeedSwitch, Utils.degToRad(18 * self.reelSpeedAdjustMode),0 ,0);
	end;
	
	if self.reelLiftSwitch ~= nil then
		setRotation(self.reelLiftSwitch, Utils.degToRad(-18 * self.sideArmAdjustMode),0 ,0);
	end;
	
	if self.reelForwardSwitch ~= nil then
		setRotation(self.reelForwardSwitch, Utils.degToRad(18 * self.sideArmFwdAdjustMode),0 ,0);
	end;
	
	self.unloading = false;
	if self.lastGrainLevel > self.grainTankFillLevel then
		self.unloading = true;
	else
		self.unloading = false;
	end;
	if self.grainUnloadHandle ~= nil then
		local x, y, z = getRotation(self.grainUnloadHandle.node);
		local rot = {x,y,z};
		local newRot = Utils.getMovedLimitedValues(rot, self.grainUnloadHandle.maxRot, self.grainUnloadHandle.minRot, 3, self.grainUnloadHandle.rotTime, dt, self.unloading);
		setRotation(self.grainUnloadHandle.node, unpack(newRot));
	end;
	
	if self.isMotorStarted then
		if self.rotationPartTanknadel ~= nil then
			local x, y, z = getRotation(self.rotationPartTanknadel.node);
			y = ((self.rotationPartTanknadel.maxRot[2] - self.rotationPartTanknadel.minRot[2]) / self.fuelCapacity) * self.fuelFillLevel + self.rotationPartTanknadel.minRot[2];
			setRotation(self.rotationPartTanknadel.node, x, y ,z);
		end;
	
		if self.rotationPartTanknadel2 ~= nil then
			local x, y, z = getRotation(self.rotationPartTanknadel2.node);
			y = ((self.rotationPartTanknadel2.maxRot[2] - self.rotationPartTanknadel2.minRot[2]) / self.fuelCapacity) * self.fuelFillLevel + self.rotationPartTanknadel2.minRot[2];
			setRotation(self.rotationPartTanknadel2.node, x, y ,z);
		end;
		
		if self.rotationPartTanknadel ~= nil then
			setRotation(self.rotationPartVoltnadel.node, 0, Utils.degToRad(-20) ,0);
		end;
		
		if self.rotationPartTanknadel ~= nil then
			setRotation(self.rotationPartOilPreasurenadel.node, 0, Utils.degToRad(10) ,0);
		end;
		
		if self.rotationPartTanknadel ~= nil then
			setRotation(self.rotationPartTempnadel.node, 0, Utils.degToRad(15) ,0);
		end;
	else
		setRotation(self.rotationPartTanknadel.node, 0, Utils.degToRad(50) ,0);
		setRotation(self.rotationPartVoltnadel.node, 0, Utils.degToRad(50) ,0);
		setRotation(self.rotationPartOilPreasurenadel.node, 0, Utils.degToRad(50) ,0);
		setRotation(self.rotationPartTempnadel.node, 0, Utils.degToRad(50) ,0);
	end;
	
	if self.isHired or self.isEntered then
		if 	self.hydroStatHandle ~= nil then
			local hydro = math.floor((self.hydro+2.5)/5)*5;
			local xRotation = 30 / 100 * hydro;
			--local direction = self.movingDirection;
			
			if self.motor.speedLevel == 0 then
				if self.hydro > 0 then
					setRotation(self.hydroStatHandle, Utils.degToRad(xRotation), 0 ,Utils.degToRad(-5));
				elseif self.hydro < 0 then
					setRotation(self.hydroStatHandle, Utils.degToRad(xRotation), 0 ,Utils.degToRad(5));
				else
					setRotation(self.hydroStatHandle, 0, 0 ,0);
				end;
			elseif self.motor.speedLevel ~= 0 then
				xRotation = 30/34 * self.lastSpeed*3600;
				
				if self.hydro > 0 then
					setRotation(self.hydroStatHandle, Utils.degToRad(xRotation), 0 ,Utils.degToRad(-5));
				elseif self.hydro < 0 then
					setRotation(self.hydroStatHandle, Utils.degToRad(-xRotation), 0 ,Utils.degToRad(5));
				else
					setRotation(self.hydroStatHandle, 0, 0 ,0);
				end;
			end;
		end;
		
		if self.rpmHandle ~= nil then
			if rpm > 1 then
				setRotation(self.rpmHandle, Utils.degToRad(15.8 * rpm), 0 ,0);
			else
				setRotation(self.rpmHandle, Utils.degToRad(0), 0 ,0);
			end;
		end;
	end;
	
	if self.gearShifter ~= nil then
		if self.motor.speedLevel ~= 0 then
			setRotation(self.gearShifter, Utils.degToRad(-10), Utils.degToRad(0), Utils.degToRad(15));
		else
			if self.gearNum == 1 then
				setRotation(self.gearShifter, Utils.degToRad(10), Utils.degToRad(0), Utils.degToRad(15));
			elseif self.gearNum == 2 then
				setRotation(self.gearShifter, Utils.degToRad(-10), Utils.degToRad(0), Utils.degToRad(-15));
			else
				setRotation(self.gearShifter, Utils.degToRad(-10), Utils.degToRad(0), Utils.degToRad(15));
			end;
		end;
	end;
	
-- Threashing off --
	if not self.isMotorStarted then
		self.ThreshingActive = false;
		self.ThreshingSound = false;
		self.BatteurOK = false;
	    self.BatteurStartPlaying = false;
	    self.BatteurStopPlaying = false;
	    self.BatteurPlaying = false;
		if self.BatteurPlaying ~= nil then
			stopSample(self.BatteurSoundId);
		end;
		if self.threshingSound ~= nil then
			stopSample(self.threshingSound);
		end;
	end	

	if not self.isEntered then
	    self.BatteurStartPlaying = false;
	    self.BatteurStopPlaying = false;
	    self.BatteurPlaying = false;
	end;

	-- Threshing conditions --
	
	if self.BatteurOK and self.isMotorStarted then
		self.allowsThreshing = true;
	else
		self.allowsThreshing = false;	
	end;

	-- Animations ---

	--if self.grainTankFillLevel > 0 and not self.Go.Batteur then
		--self.Go.Batteur = true;
		--self.Done.Batteur = true;
	--end;
	
	-- Ha Treshed --
		--self.TreshedNumber = g_currentMission.missionStats.hectaresThreshedSession
		
		if self.isThreshing then
		local pixelToQm = 2048 / 4096 * 2048 / 4096; -- 4096px are mapped to 2048m
		self.TreshedNumber = self.TreshedNumber + self.lastArea*pixelToQm/(40000);
		self.TreshedTotalNumber = self.TreshedTotalNumber + self.lastArea*pixelToQm/(40000);
		end;
	
			--self.TESTNUMBER = g_currentMission.missionStats.hectaresThreshedSession;
	-- Hide/Show Parts --
	
	if self.reverseDriveSoundEnabled then
		setVisibility(self.backward_lights, true);
	else
		setVisibility(self.backward_lights, false);
    	end;

	if self.RetroActive then
		setVisibility(self.retroG, true);
		setVisibility(self.retroD, true);
	else
		setVisibility(self.retroG, false);
		setVisibility(self.retroD, false);
	end;

	self.lastGrainLevel = self.grainTankFillLevel;

end;

function IH1480:onLeave()
	if not self.isHired then
		self.rotationColonneMin = false;
		self.rotationColonneMax = true;
	end;
end;

function IH1480:onEnter()
		self.rotationColonneMin = true;
		self.rotationColonneMax = false;
end;

function IH1480:draw()
if self.isEntered then
		g_currentMission:addExtraPrintText(string.format("Touche 0: HUD ON/OFF"));
		g_currentMission:addExtraPrintText(string.format("Touche %s/%s : Rpm +/-", InputBinding.getKeyNamesOfDigitalAction(InputBinding.JDTRPMUP), InputBinding.getKeyNamesOfDigitalAction(InputBinding.JDTRPMDOWN)));
		g_currentMission:addExtraPrintText(string.format("Touche %s/%s: Gear +/-", InputBinding.getKeyNamesOfDigitalAction(InputBinding.JDTSPEEDUP), InputBinding.getKeyNamesOfDigitalAction(InputBinding.JDTSPEEDDOWN)));
		g_currentMission:addExtraPrintText(string.format("Touche %s: Start/Stop engine", InputBinding.getKeyNamesOfDigitalAction(InputBinding.JDTIGNITION)));
		if self.HUDOverlay ~= nil then
			if self.HUDActive then
				self.HUDOverlay:render();
				setTextBold(true);
				setTextColor(0, 0, 0, 1.0);
				renderText(0.96, 0.22, 0.016, string.format("%.1f", self.TreshedNumber));
				renderText(0.96, 0.205, 0.016, string.format("%.1f", self.TreshedTotalNumber));
				--renderText(0.5, 0.9350, 0.040, string.format(self.RandomNumber));

			end;
		end;
	end;
end;


function IH1480:onDeactivateSounds()
    if self.BatteurPlaying ~= nil then
		stopSample(self.BatteurSoundId);
    end;
end;

